==> qtjambi-scxml-debuginfo-linux-x64-6.5.4.jar: sources/QtJambiScxml/QScxmlExecutableContent_ForeachInfo_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtScxml/qscxmlexecutablecontent.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QScxmlExecutableContent_ForeachInfo(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QScxmlExecutableContent::ForeachInfo")
    QScxmlExecutableContent::ForeachInfo *_ptr = reinterpret_cast<QScxmlExecutableContent::ForeachInfo *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QScxmlExecutableContent_ForeachInfo_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QScxmlExecutableContent::ForeachInfo *__qt_this = new(__qtjambi_ptr) QScxmlExecutableContent::ForeachInfo();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QScxmlExecutableContent::ForeachInfo
void __qt_destruct_QScxmlExecutableContent_ForeachInfo(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QScxmlExecutableContent::ForeachInfo")
    reinterpret_cast<QScxmlExecutableContent::ForeachInfo*>(ptr)->~ForeachInfo();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QScxmlExecutableContent::ForeachInfo::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlExecutableContent_00024ForeachInfo_initialize_1native__Lio_qt_scxml_QScxmlExecutableContent_00024ForeachInfo_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QScxmlExecutableContent::ForeachInfo::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QScxmlExecutableContent_ForeachInfo_0, sizeof(QScxmlExecutableContent::ForeachInfo), typeid(QScxmlExecutableContent::ForeachInfo), false, &deleter_QScxmlExecutableContent_ForeachInfo, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlExecutableContent_00024ForeachInfo_setArray_1native_1qint32__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint array0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QScxmlExecutableContent::ForeachInfo *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlExecutableContent::ForeachInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->array = static_cast<qint32>(array0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlExecutableContent_00024ForeachInfo_array_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QScxmlExecutableContent::ForeachInfo *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlExecutableContent::ForeachInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qint32  __qt_value = __qt_this->array;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlExecutableContent_00024ForeachInfo_setContext_1native_1qint32__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint context0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QScxmlExecutableContent::ForeachInfo *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlExecutableContent::ForeachInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->context = static_cast<qint32>(context0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlExecutableContent_00024ForeachInfo_context_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QScxmlExecutableContent::ForeachInfo *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlExecutableContent::ForeachInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qint32  __qt_value = __qt_this->context;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlExecutableContent_00024ForeachInfo_setIndex_1native_1qint32__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint index0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QScxmlExecutableContent::ForeachInfo *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlExecutableContent::ForeachInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->index = static_cast<qint32>(index0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlExecutableContent_00024ForeachInfo_index_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QScxmlExecutableContent::ForeachInfo *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlExecutableContent::ForeachInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qint32  __qt_value = __qt_this->index;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlExecutableContent_00024ForeachInfo_setItem_1native_1qint32__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint item0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QScxmlExecutableContent::ForeachInfo *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlExecutableContent::ForeachInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->item = static_cast<qint32>(item0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlExecutableContent_00024ForeachInfo_item_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QScxmlExecutableContent::ForeachInfo *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlExecutableContent::ForeachInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qint32  __qt_value = __qt_this->item;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlExecutableContent_00024ForeachInfo_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QScxmlExecutableContent::ForeachInfo *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlExecutableContent::ForeachInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QScxmlExecutableContent_ForeachInfo(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QScxmlExecutableContent::ForeachInfo>("QScxmlExecutableContent::ForeachInfo", "io/qt/scxml/QScxmlExecutableContent$ForeachInfo");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QScxmlExecutableContent_ForeachInfo, {
        ConstructorInfo(&__qt_construct_QScxmlExecutableContent_ForeachInfo_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QScxmlExecutableContent_ForeachInfo);
    registerMetaType<QScxmlExecutableContent::ForeachInfo>("QScxmlExecutableContent::ForeachInfo");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-scxml-debuginfo-linux-x64-6.6.3.jar: sources/QtJambiScxml/QScxmlExecutableContent_ForeachInfo_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtScxml/qscxmlexecutablecontent.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QScxmlExecutableContent_ForeachInfo(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QScxmlExecutableContent::ForeachInfo")
    QScxmlExecutableContent::ForeachInfo *_ptr = reinterpret_cast<QScxmlExecutableContent::ForeachInfo *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new ForeachInfo()
void __qt_construct_QScxmlExecutableContent_ForeachInfo(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ForeachInfo()")
    Q_UNUSED(__java_arguments)
    QScxmlExecutableContent::ForeachInfo *__qt_this = new(__qtjambi_ptr) QScxmlExecutableContent::ForeachInfo();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QScxmlExecutableContent::ForeachInfo::ForeachInfo()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlExecutableContent_00024ForeachInfo_initialize_1native__Lio_qt_scxml_QScxmlExecutableContent_00024ForeachInfo_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QScxmlExecutableContent::ForeachInfo::ForeachInfo()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QScxmlExecutableContent_ForeachInfo, sizeof(QScxmlExecutableContent::ForeachInfo), typeid(QScxmlExecutableContent::ForeachInfo), false, &deleter_QScxmlExecutableContent_ForeachInfo, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new ForeachInfo(QScxmlExecutableContent::ForeachInfo)
void __qt_construct_QScxmlExecutableContent_ForeachInfo_cref_QScxmlExecutableContent_ForeachInfo(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ForeachInfo(QScxmlExecutableContent::ForeachInfo)")
    jobject other0 = __java_arguments[0].l;
    const QScxmlExecutableContent::ForeachInfo& __qt_other0 = qtjambi_cast<const QScxmlExecutableContent::ForeachInfo& >(__jni_env, other0);
    QScxmlExecutableContent::ForeachInfo *__qt_this = new(__qtjambi_ptr) QScxmlExecutableContent::ForeachInfo(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QScxmlExecutableContent::ForeachInfo::ForeachInfo(QScxmlExecutableContent::ForeachInfo)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlExecutableContent_00024ForeachInfo_initialize_1native__Lio_qt_scxml_QScxmlExecutableContent_00024ForeachInfo_2Lio_qt_scxml_QScxmlExecutableContent_00024ForeachInfo_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QScxmlExecutableContent::ForeachInfo::ForeachInfo(QScxmlExecutableContent::ForeachInfo)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QScxmlExecutableContent_ForeachInfo_cref_QScxmlExecutableContent_ForeachInfo, sizeof(QScxmlExecutableContent::ForeachInfo), typeid(QScxmlExecutableContent::ForeachInfo), false, &deleter_QScxmlExecutableContent_ForeachInfo, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new ForeachInfo{qint32,qint32,qint32,qint32}
void __qt_construct_QScxmlExecutableContent_ForeachInfo_qint32_qint32_qint32_qint32(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ForeachInfo{qint32,qint32,qint32,qint32}")
    jint array0 = __java_arguments[0].i;
    Q_UNUSED(array0)
    jint item1 = __java_arguments[1].i;
    Q_UNUSED(item1)
    jint index2 = __java_arguments[2].i;
    Q_UNUSED(index2)
    jint context3 = __java_arguments[3].i;
    Q_UNUSED(context3)
    QScxmlExecutableContent::ForeachInfo *__qt_this = new(__qtjambi_ptr) QScxmlExecutableContent::ForeachInfo{static_cast<qint32>(array0), static_cast<qint32>(item1), static_cast<qint32>(index2), static_cast<qint32>(context3)};
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QScxmlExecutableContent::ForeachInfo::ForeachInfo{qint32,qint32,qint32,qint32}
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlExecutableContent_00024ForeachInfo_initialize_1native__Lio_qt_scxml_QScxmlExecutableContent_00024ForeachInfo_2IIII)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jint array0,
 jint item1,
 jint index2,
 jint context3)
{
    QTJAMBI_NATIVE_METHOD_CALL("QScxmlExecutableContent::ForeachInfo::ForeachInfo{qint32,qint32,qint32,qint32}")
    QTJAMBI_TRY {
        jvalue arguments[4];
        arguments[0].i = array0;
        arguments[1].i = item1;
        arguments[2].i = index2;
        arguments[3].i = context3;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QScxmlExecutableContent_ForeachInfo_qint32_qint32_qint32_qint32, sizeof(QScxmlExecutableContent::ForeachInfo), typeid(QScxmlExecutableContent::ForeachInfo), false, &deleter_QScxmlExecutableContent_ForeachInfo, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QScxmlExecutableContent::ForeachInfo
void __qt_destruct_QScxmlExecutableContent_ForeachInfo(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QScxmlExecutableContent::ForeachInfo")
    reinterpret_cast<QScxmlExecutableContent::ForeachInfo*>(ptr)->~ForeachInfo();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlExecutableContent_00024ForeachInfo_setArray_1native_1qint32__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint array0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QScxmlExecutableContent::ForeachInfo *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlExecutableContent::ForeachInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->array = static_cast<qint32>(array0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlExecutableContent_00024ForeachInfo_array_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QScxmlExecutableContent::ForeachInfo *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlExecutableContent::ForeachInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qint32  __qt_value = __qt_this->array;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlExecutableContent_00024ForeachInfo_setContext_1native_1qint32__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint context0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QScxmlExecutableContent::ForeachInfo *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlExecutableContent::ForeachInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->context = static_cast<qint32>(context0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlExecutableContent_00024ForeachInfo_context_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QScxmlExecutableContent::ForeachInfo *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlExecutableContent::ForeachInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qint32  __qt_value = __qt_this->context;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlExecutableContent_00024ForeachInfo_setIndex_1native_1qint32__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint index0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QScxmlExecutableContent::ForeachInfo *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlExecutableContent::ForeachInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->index = static_cast<qint32>(index0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlExecutableContent_00024ForeachInfo_index_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QScxmlExecutableContent::ForeachInfo *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlExecutableContent::ForeachInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qint32  __qt_value = __qt_this->index;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlExecutableContent_00024ForeachInfo_setItem_1native_1qint32__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint item0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QScxmlExecutableContent::ForeachInfo *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlExecutableContent::ForeachInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->item = static_cast<qint32>(item0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlExecutableContent_00024ForeachInfo_item_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QScxmlExecutableContent::ForeachInfo *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlExecutableContent::ForeachInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qint32  __qt_value = __qt_this->item;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlExecutableContent_00024ForeachInfo_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QScxmlExecutableContent::ForeachInfo *__qt_this = QtJambiAPI::objectFromNativeId<QScxmlExecutableContent::ForeachInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QScxmlExecutableContent_ForeachInfo(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QScxmlExecutableContent::ForeachInfo>("QScxmlExecutableContent::ForeachInfo", "io/qt/scxml/QScxmlExecutableContent$ForeachInfo");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QScxmlExecutableContent_ForeachInfo, {
        ConstructorInfo(&__qt_construct_QScxmlExecutableContent_ForeachInfo, nullptr)
       ,ConstructorInfo(&__qt_construct_QScxmlExecutableContent_ForeachInfo_cref_QScxmlExecutableContent_ForeachInfo, "Lio/qt/scxml/QScxmlExecutableContent$ForeachInfo;")
       ,ConstructorInfo(&__qt_construct_QScxmlExecutableContent_ForeachInfo_qint32_qint32_qint32_qint32, "IIII")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QScxmlExecutableContent_ForeachInfo);
    registerMetaType<QScxmlExecutableContent::ForeachInfo>("QScxmlExecutableContent::ForeachInfo");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
